from datetime import datetime
from typing import List, Optional, Dict, Any

from janis_core import *
from janis_core.types.common_data_types import File, Int, String, Boolean

Proteinquantifier_V0_1_0 = CommandToolBuilder(tool="ProteinQuantifier", base_command=["ProteinQuantifier"], inputs=[ToolInput(tag="in_in", input_type=File(optional=True), prefix="-in", doc=InputDocumentation(doc="*               Input file (valid formats: 'featureXML', 'consensusXML', 'idXML')")), ToolInput(tag="in_protein_groups", input_type=File(optional=True), prefix="-protein_groups", doc=InputDocumentation(doc="Protein inference results for the identification runs that were used to annotate the input (e.g. from ProteinProphet via IDFileConverter or Fido via FidoAdapter).\nInformation about indistinguishable proteins will be used for protein quantification. (valid formats: 'idXML')")), ToolInput(tag="in_out", input_type=File(optional=True), prefix="-out", doc=InputDocumentation(doc="Output file for protein abundances (valid formats: 'csv')")), ToolInput(tag="in_peptide_out", input_type=File(optional=True), prefix="-peptide_out", doc=InputDocumentation(doc="Output file for peptide abundances (valid formats: 'csv')")), ToolInput(tag="in_top", input_type=Int(optional=True), prefix="-top", doc=InputDocumentation(doc="Calculate protein abundance from this number of proteotypic peptides (most abundant first; '0' for all) (default: '3' min: '0')")), ToolInput(tag="in_average", input_type=String(optional=True), prefix="-average", doc=InputDocumentation(doc="Averaging method used to compute protein abundances from peptide abundances (default: 'median' valid: 'median', 'mean', 'weighted_mean', 'sum')")), ToolInput(tag="in_include_all", input_type=Boolean(optional=True), prefix="-include_all", doc=InputDocumentation(doc="Include results for proteins with fewer proteotypic peptides than indicated by 'top' (no effect if 'top' is 0 or 1)")), ToolInput(tag="in_filter_charge", input_type=Boolean(optional=True), prefix="-filter_charge", doc=InputDocumentation(doc="Distinguish between charge states of a peptide. For peptides, abundances will be reported separately for each charge;\nfor proteins, abundances will be computed based only on the most prevalent charge of each peptide.\nBy default, abundances are summed over all charge states.")), ToolInput(tag="in_ratios", input_type=Boolean(optional=True), prefix="-ratios", doc=InputDocumentation(doc="Add the log2 ratios of the abundance values to the output. Format: log_2(x_0/x_0) <sep> log_2(x_1/x_0) <sep> log_2(x_2/x_0) ...")), ToolInput(tag="in_ratios_sila_c", input_type=Boolean(optional=True), prefix="-ratiosSILAC", doc=InputDocumentation(doc="Add the log2 ratios for a triple SILAC experiment to the output. Only applicable to consensus maps of exactly three sub-maps. Format: log_2(heavy/light) <sep> log_2(heavy/middle) <sep> log_2(middle/light)")), ToolInput(tag="in_ini", input_type=File(optional=True), prefix="-ini", doc=InputDocumentation(doc="Use the given TOPP INI file")), ToolInput(tag="in_threads", input_type=Int(optional=True), prefix="-threads", doc=InputDocumentation(doc="Sets the number of threads allowed to be used by the TOPP tool (default: '1')")), ToolInput(tag="in_write_ini", input_type=File(optional=True), prefix="-write_ini", doc=InputDocumentation(doc="Writes the default configuration file")), ToolInput(tag="in_helphelp", input_type=Boolean(optional=True), prefix="--helphelp", doc=InputDocumentation(doc="Shows all options (including advanced)"))], outputs=[ToolOutput(tag="out_out", output_type=File(optional=True), selector=InputSelector(input_to_select="in_out", type_hint=File()), doc=OutputDocumentation(doc="Output file for protein abundances (valid formats: 'csv')")), ToolOutput(tag="out_peptide_out", output_type=File(optional=True), selector=InputSelector(input_to_select="in_peptide_out", type_hint=File()), doc=OutputDocumentation(doc="Output file for peptide abundances (valid formats: 'csv')"))], container=None, version="v0.1.0")


if __name__ == "__main__":
    # or "cwl"
    Proteinquantifier_V0_1_0().translate("wdl", allow_empty_container=True)

